tlslite.integration.POP3_TLS

Package tlslite :: Package integration :: Module POP3_TLS |
[show private | hide private]
[frames | no frames]

## Module tlslite.integration.POP3_TLS

TLS Lite + poplib.

Classes
`POP3_TLS` | This class extends `poplib.POP3` with TLS support.

Variable Summary
`int` | `POP3_TLS_PORT` = 995

Variable Details

    ### POP3_TLS_PORT Type: `int` Value:
        995

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net